import os
import requests


output_file = "env_vars.sh"
if os.path.exists(output_file):
    os.remove(output_file)
def export_env_vars_from_vault(path):
    VAULT_TOKEN = "hvs.4ogyPJGV9Y9AEqNpBNAVmgdU"
    VAULT_ADDR = "https://vault.allence.cloud"
    headers = {"X-Vault-Token": VAULT_TOKEN}
    print(path)
    url = f"{VAULT_ADDR}/v1/{str(path)}"
    print(url)
    response = requests.get(url, headers=headers)

    # Check if the request was successful
    if response.status_code == 200:
        data = response.json()["data"]["data"]
        with open(output_file, "a") as script_file:
            # Iterate over the keys in the response data
            for key, value in data.items():
                # Export the key-value pair as environment variables
                os.environ[key] = value
                script_file.write(f"export {key}='{value}'\n")
                print(value)

    else:
        print(f"Failed to fetch secrets from Vault or no secrets in vault {path} . Status code: {response.status_code}")
def get_secrets_path(input_str):
    l=[]
    parts = input_str.strip('/').split('/')
    if 'builds' in parts:
        index = parts.index('builds')
        for i in range(index + 1, len(parts)):
            os.environ[f"{chr(ord('A') + i - index - 1)}"] = parts[i]
            l.append(parts[i])
    return l

input_str ="/builds/commons-acp/docker-images/terraform" #os.getenv("CI_PROJECT_DIR")

if len(get_secrets_path(input_str))==2:
    for var in ['A', 'B']:
        var=os.environ.get(var)
    GP=f"{os.environ.get('A')}/data/variables"
    export_env_vars_from_vault(GP)
    G1=f"{os.environ.get('A')}/data/{os.environ.get('B')}"
    export_env_vars_from_vault(G1)

elif len(get_secrets_path(input_str))==3:
    for var in ['A', 'B','C']:
        var=os.environ.get(var)
    GP=f"{os.environ.get('A')}/data/variables"
    export_env_vars_from_vault(GP)
    G1=f"{os.environ.get('A')}/data/{os.environ.get('B')}/variables"
    export_env_vars_from_vault(G1)
    G2=f"{os.environ.get('A')}/data/{os.environ.get('B')}/{os.environ.get('C')}"
    export_env_vars_from_vault(G2)
elif len(get_secrets_path(input_str))==4:
    for var in ['A', 'B','C','D']:
        var=os.environ.get(var)
    GP=f"{os.environ.get('A')}/data/variables"
    export_env_vars_from_vault(GP)
    G1=f"{os.environ.get('A')}/data/{os.environ.get('B')}/variables"
    export_env_vars_from_vault(G1)
    G2=f"{os.environ.get('A')}/data/{os.environ.get('B')}/{os.environ.get('C')}/variables"
    export_env_vars_from_vault(G2)
    G3=f"{os.environ.get('A')}/data/{os.environ.get('B')}/{os.environ.get('C')}/{os.environ.get('D')}"
    export_env_vars_from_vault(G3)
elif len(get_secrets_path(input_str))==5:
    for var in ['A', 'B','C','D','E']:
        var=os.environ.get(var)
    GP=f"{os.environ.get('A')}/data/variables"
    export_env_vars_from_vault(GP)
    G1=f"{os.environ.get('A')}/data/{os.environ.get('B')}/variables"
    export_env_vars_from_vault(G1)
    G2=f"{os.environ.get('A')}/data/{os.environ.get('B')}/{os.environ.get('C')}/variables"
    export_env_vars_from_vault(G2)
    G3=f"{os.environ.get('A')}/data/{os.environ.get('B')}/{os.environ.get('C')}/{os.environ.get('D')}/variables"
    export_env_vars_from_vault(G3)
    G4=f"{os.environ.get('A')}/data/{os.environ.get('B')}/{os.environ.get('C')}/{os.environ.get('D')}/{os.environ.get('E')}"
    export_env_vars_from_vault(G4)


from setuptools import setup
import semver


# Read the current version from the VERSION file
with open('VERSION', 'r') as f:
    current_version_string = f.read().strip()
    print(type(current_version_string))
# Strip the decimal point before parsing as an integer 
current_version = semver.Version.parse(current_version_string)
print("currrent version ",current_version)



# Increment the patch version
new_version = current_version.bump_patch()

with open('VERSION', 'w') as f:
    f.write(str(new_version))
print("new version ",new_version)

"""
setup(
    name='my-project',
    version=str(new_version),
    description='My awesome project',
    author='Your Name',
    author_email='youremail@example.com',
    url='https://github.com/your-username/my-project',
    packages=['my_project'],
)
"""



import os
import requests
import gitlab
import sys
auto_mr_dev=False
auto_mr_uat=False
auto_mr_prod=False


if "true"==str(os.environ.get("AUTO_APPLY_DEV")).lower():
    auto_mr_dev=True
if "true"==str(os.environ.get("AUTO_APPLY_UAT")).lower():
    auto_mr_uat=True
if "true"== str(os.environ.get("AUTO_APPLY_PROD")).lower():
    auto_mr_prod=True

git_url="https://gitlab.allence.cloud"
if len(sys.argv) > 1:
    git_url = sys.argv[1]

merge_id = os.environ.get('CI_MERGE_REQUEST_IID')
project_id=os.environ.get('CI_PROJECT_ID')
gitlab_token=os.environ.get('gitlab_token')
gl = gitlab.Gitlab(git_url,private_token = gitlab_token)
project = gl.projects.get(project_id)
mr= project.mergerequests.get(merge_id)
changeList=[]
mrchange=mr.changes()
changes = mrchange['changes']
if (len(changes)==0):
    print("no changes detected in this mr")
    changeList.append("no changes detected in this mr")
else:
    for change in changes:
        newPath=change['new_path']
        if("live/1-dev") in newPath and auto_mr_dev==False:
            print("auto mr is disabled in dev, found changes in:" +newPath)
            changeList.append("auto mr is disabled in dev, found changes in:" +newPath)

        if("live/2-uat") in newPath and auto_mr_uat==False:
            print("auto mr is disabled in uat, found changes in:" +newPath)
            changeList.append("auto mr is disabled in uat, found changes in:" +newPath)
        if("live/3-prod") in newPath and auto_mr_prod==False:
            print("auto mr is disabled in prod, found changes in:" +newPath)
            changeList.append("auto mr is disabled in prod, found changes in:" +newPath)

if not changeList:
    base_url = "https://gitlab.allence.cloud/api/v4/projects/"+str(project_id)+"/merge_requests/"+str(merge_id)+"/merge?private_token="+gitlab_token#/merge"
    #print(base_url)
    merge =  requests.put(base_url)
    print(str(merge))
    if 'Branch cannot be merged' in str(merge) :
        base_url = "https://gitlab.allence.cloud/api/v4/projects/"+str(project_id)+"/merge_requests/"+str(merge_id)+"/rebase?private_token="+gitlab_token#/merge"
        rebase =  requests.put(base_url)
        print(str(rebase))



from boto3 import client


def log_func(env, functions):
    print(f"\n\n{env} Functions:\n")
    for function in functions:
        print(
            function["FunctionName"],
            function["Environment"]["Variables"]["VERSION"],
            function["Runtime"],
            function["LastModified"],
            sep=" / ",
        )


def generate_tf_file(env, lambdas):
    if env == "DEV":
        file_name = (
            "live/aws/01-dev/020427942281/eu-west-1/versions/data_template_file.tf"
        )
    elif env == "UAT":
        file_name = (
            "live/aws/02-uat/020427942281/eu-west-1/versions/data_template_file.tf"
        )
    elif env == "UATM":
        file_name = "live/aws/03-uatm/versions/data_template_file.tf"
    elif env == "PROD":
        file_name = (
            "live/aws/04-prod/020427942281/eu-west-1/versions/data_template_file.tf"
        )
    template_file_block = (
        "template = jsonencode({\n"
        + ",\n".join(
            [
                f"{project['name']} = {{ version = \"{project['version']}\", date = \"{project['date']}\" }}"
                for project in lambdas
            ]
        )
        + "\n})"
    )

    terraform_config = f"""
data "template_file" "lambda_versions_template" {{
    {template_file_block}
}}
"""
    with open(file_name, "w") as f:
        f.write(terraform_config)


def extract_variables(lambdas, functions):
    EXCLUDED_FUNCTIONS = [
        "facturation_dev",
        "facturation_uat",
        "facturation_uatm",
        "facturation_prod",
        "extract_salary_DEV",
        "extract_salary_UAT",
        "extract_salary_UATM",
        "extract_salary_PROD",
        "lambda_pdf2text_dev",
        "lambda_pdf2text_uat",
        "lambda_pdf2text_uatm",
        "lambda_pdf2text_prod",
        "extract_salary_pdf_DEV",
        "extract_salary_pdf_UAT",
        "extract_salary_pdf_UATM",
        "extract_salary_pdf_PROD",
        "archive_UAT",
        "archive_prod",
        "lambda_monitoring_dev",
    ]
    for function in functions:
        func_name = function["FunctionName"].replace("-", "_")
        if func_name not in EXCLUDED_FUNCTIONS:
            lambdas.append(
                {
                    "name": func_name,
                    "version": function["Environment"]["Variables"]["VERSION"],
                    "date": function["LastModified"].split("T")[0],
                }
            )


if __name__ == "__main__":
    lambda_client = client("lambda")
    response = lambda_client.list_functions()
    dev_functions, dev_lambdas = [], []
    uat_functions, uat_lambdas = [], []
    uatm_functions, uatm_lambdas = [], []
    prod_functions, prod_lambdas = [], []
    while True:
        functions = response["Functions"]
        for function in functions:
            if function.get("Environment"):
                if function["Environment"]["Variables"].get("VERSION"):
                    func_name = function["FunctionName"].lower()
                    if "dev" in func_name:
                        dev_functions.append(function)
                    elif "uat" in func_name and not "uatm" in func_name:
                        uat_functions.append(function)
                    elif "uatm" in func_name:
                        uatm_functions.append(function)
                    elif "prod" in func_name:
                        prod_functions.append(function)

        # Check if there are more results
        if "NextMarker" in response:
            pagination_token = response["NextMarker"]
            response = lambda_client.list_functions(Marker=pagination_token)
        else:
            break

    for env, functions in [
        ("DEV", dev_functions),
        ("UAT", uat_functions),
        ("UATM", uatm_functions),
        ("PROD", prod_functions),
    ]:
        log_func(env, functions)
        if env == "DEV":
            extract_variables(dev_lambdas, functions)
            generate_tf_file(env, dev_lambdas)
        elif env == "UAT":
            extract_variables(uat_lambdas, functions)
            generate_tf_file(env, uat_lambdas)
        elif env == "UATM":
            extract_variables(uatm_lambdas, functions)
            generate_tf_file(env, uatm_lambdas)
        elif env == "PROD":
            extract_variables(prod_lambdas, functions)
            generate_tf_file(env, prod_lambdas)



import os

import requests

gitlab_token = os.environ["gitlab_token"]
headers = {"PRIVATE-TOKEN": gitlab_token}
project_id = os.environ["CI_PROJECT_ID"]
base_url = "https://gitlab.allence.cloud/api/v4/projects/" + str(project_id)

req_mrs = requests.get(
    f"{base_url}/merge_requests?state=opened", headers=headers
).json()

for mr in req_mrs:
    request = requests.put(
        f"{base_url}/merge_requests/{mr['iid']}/rebase", headers=headers
    )
    print(f"MR {mr['iid']} is rebased with status: {request.status_code}")
    last_commit = requests.get(
        f"{base_url}/repository/commits/{mr['sha']}", headers=headers
    ).json()
    print(last_commit)



import json
import os
import pathlib
import shutil
import subprocess
import sys
from os import listdir
from os.path import isdir, join

import gitlab
import requests

import terragit.terragrunt as terraconf

pathList = []
failedloglist = []
logsFolder = ""
printLogs = False


class Validate:
    def __init__(self):
        self.bcolor = terraconf.bcolors

    def validate_ci(self):
        global printLogs
        git_url = "https://gitlab.com/"
        if len(sys.argv) > 1:
            git_url = sys.argv[1]
        logsFolder = pathlib.Path("logs").absolute().as_posix()
        failedlogsFolder = pathlib.Path("failedlogs").absolute().as_posix()
        idMr = str(os.environ.get("CI_MERGE_REQUEST_IID"))
        idProject = int(str(os.environ.get("CI_PROJECT_ID")))
        gitlab_token = str(os.environ.get("gitlab_token"))
        ci_commit_title = str(os.environ.get("CI_COMMIT_TITLE"))
        gl = gitlab.Gitlab(
            url=git_url, private_token=gitlab_token
        )
        project = gl.projects.get(idProject)
        mr = project.mergerequests.get(idMr)
        folderList = []
        mrchange = mr.changes()
        changes = mrchange["changes"]  # type: ignore
        if len(changes) == 0:
            if not isdir(pathlib.Path(ci_commit_title).absolute().as_posix()):
                print(
                    self.bcolor.FAIL
                    + ci_commit_title
                    + " is not valid path"
                    + self.bcolor.ENDC
                )
                failedloglist.append(ci_commit_title)
            else:
                ci_mr_titlePath = pathlib.Path(ci_commit_title).absolute().as_posix()
                printLogs = True
                self.validate_all(ci_mr_titlePath, logsFolder, printLogs)
        else:
            for change in changes:
                newPath = change["new_path"]
                if not ("live/") in newPath:
                    print(
                        pathlib.Path(newPath).absolute().as_posix()
                        + self.bcolor.WARNING
                        + " OUT of SCOPE"
                        + self.bcolor.ENDC
                    )
                else:
                    pathh = pathlib.Path(newPath).parent.absolute().as_posix()
                    folderList.append(pathh)
        mylist = list(dict.fromkeys(folderList))
        if os.environ.get("TG_OUTPUT_LIMIT"):
            TG_OUTPUT_LIMIT = int(str(os.environ.get("TG_OUTPUT_LIMIT")))
        else:
            TG_OUTPUT_LIMIT = 3
        if len(mylist) <= TG_OUTPUT_LIMIT and any(".hcl" in l for l in mylist):
            printLogs = True
        for path in mylist:
            if isdir(path):
                self.validate_all(path, logsFolder, printLogs)
        if failedloglist:
            for message in failedloglist:
                logfileName = message.split("live/")[1].replace("/", "_")
                os.chdir(failedlogsFolder)
                shutil.move(
                    logsFolder + "/" + logfileName + ".log",
                    "failed_" + logfileName + ".log",
                )
            sys.exit(1)

    def validate_all(self, path, logsFolder, printLogs):
        if path in pathList:
            return
        else:
            pathList.append(path)
            only_tf_files = [
                f
                for f in sorted(listdir(path))
                if not isdir(join(path, f)) and f.endswith(".tf")
            ]
            if len(only_tf_files) == 0:
                onlyDirectories = [
                    d
                    for d in sorted(listdir(path))
                    if isdir(join(path, d))
                    and d != ".terraform"
                    and d != ".terragrunt-cache"
                ]
                if len(onlyDirectories) > 0:
                    for i in range(0, len(onlyDirectories)):
                        self.validate_all(
                            path + "/" + onlyDirectories[i], logsFolder, printLogs
                        )
                return
            os.chdir(path)
            logfileName = path.split("live/")[1].replace("/", "_")
            state_list = (
                "terragrunt validate -no-color 2>&1 | tee "
                + logsFolder
                + "/"
                + logfileName
                + ".log"
            )
            popen = subprocess.Popen(
                state_list,
                stdout=subprocess.PIPE,
                shell=True,
                encoding="utf8",
                env=os.environ.copy(),
            )
            lines = popen.stdout.readlines()  # type: ignore
            popen.stdout.close()  # type: ignore
            print(self.bcolor.OKBLUE + path + ":" + self.bcolor.ENDC)
            for line in lines:
                if printLogs:
                    print(line)
                else:
                    if "Error" in line:
                        lint = lines[(lines.index(line)) : (len(lines))]
                        for l in lint:
                            print(l.replace("\n", ""))
                        failedloglist.append(path)
                        print(self.bcolor.FAIL + " COULDNT PROCESS" + self.bcolor.ENDC)
                        return
                if "Success! The configuration is valid" in line:
                    print(self.bcolor.OKGREEN + "Success." + self.bcolor.ENDC)
                    return
            print(self.bcolor.FAIL + "configuration is not valid." + self.bcolor.ENDC)
            failedloglist.append(path)




import requests
import os
import time
 

gitlab_token = os.getenv("gitlab_token")
headers = {'PRIVATE-TOKEN': gitlab_token}
base_url = "https://gitlab.allence.cloud/api/v4/projects/"

projet_infra=os.getenv("PROJET_INFRA")
projet_group=os.getenv("PROJECT_GROUP")
project_name = projet_group.replace("/","%2F")+"%2F"+projet_infra
branch_name = os.getenv("TERRAGRUNT_GIT_BRANCH")

## GET INFRA PROJECT ID
project_url = base_url+project_name
req_project = requests.get(project_url, headers=headers).json()
project_id = req_project['id']
print("project ID = "+str(project_id))
## GET INFRA MR ID
branch_url=base_url+str(project_id)+"/repository/branches/"+branch_name.replace("/","%2F")
req_branch=requests.get(branch_url, headers=headers).json()
commit_sha = req_branch['commit']['id']
print("commit ID = " +
      str(commit_sha))

mr_url=base_url+str(project_id)+"/repository/commits/"+commit_sha+"/merge_requests"
req_mr=requests.get(mr_url, headers=headers).json()
#print(req_mr)
mr_id = req_mr[0]['iid']
print("MR ID = " + str(mr_id))

time.sleep(5)
mr_url = base_url+str(project_id)+"/merge_requests/"+str(mr_id)
status = "running"
mr_validation = True
while status == "running" :
    mr_validation = True
    print("############################################")
    req_mr =requests.get(mr_url, headers=headers).json()
    status = req_mr['head_pipeline']['detailed_status']['label']
    print("The MR is " + status)
    jobs_url= base_url+str(project_id)+"/pipelines/"+str(req_mr['head_pipeline']['id'])+"/jobs"
    req_jobs = requests.get(jobs_url, headers=headers).json()
    for job in req_jobs:
        print("The Job "+job['name'] +" is "+job['status'])
        mr_validation = mr_validation and job['status'] == 'success'
    time.sleep(2)
if mr_validation:
    r = requests.put(mr_url+"/merge", headers=headers)
    print("MR "+str(req_mr['iid'])+" is Merged, status: "+str(r))
    print("Wait for the new Pipeline to be created")
    time.sleep(5)
    status = "running"
    mr_validation = True
    while status == "running" :
        print("############################################")
        commit_url= base_url+str(project_id)+"/repository/commits/"+str(req_mr['sha'])
        req_commit = requests.get(commit_url, headers=headers).json()
        mr_validation = True
        status = req_commit['last_pipeline']['status']
        jobs_url= base_url+str(project_id)+"/pipelines/"+str(req_commit['last_pipeline']['id'])+"/jobs"
        req_jobs = requests.get(jobs_url, headers=headers).json()
        for job in req_jobs:
            print("The Job "+job['name'] +" is "+job['status'])
        time.sleep(2)



import os
from argparse import ArgumentParser

import requests

try:
    from tqdm import tqdm
except ModuleNotFoundError:
    os.system(
        "pip install tqdm > /dev/null 2>&1 || pip install tqdm --break-system-packages"
    )
    from tqdm import tqdm


def export_env_vars_from_vault(path):
    VAULT_TOKEN = os.getenv("VAULT_TOKEN")
    VAULT_ADDR = "https://vault.allence.cloud"
    headers = {"X-Vault-Token": VAULT_TOKEN}
    url = f"{VAULT_ADDR}/v1/{str(path)}"
    response = requests.get(url, headers=headers)
    if response.status_code == 200:
        data = response.json()["data"]["data"]
        with open(output_file, "a") as script_file:
            for key, value in data.items():
                os.environ[key] = value
                script_file.write(f"export {key}='{value}'\n")


def get_secrets_path(input_str):
    l = []
    parts = input_str.strip("/").split("/")
    if "builds" in parts:
        index = parts.index("builds")
        for i in range(index + 1, len(parts)):
            os.environ[f"{chr(ord('A') + i - index - 1)}"] = parts[i]
            l.append(parts[i])
    return l


if __name__ == "__main__":
    output_file = "env_vars.sh"
    input_str = os.getenv("CI_PROJECT_DIR")
    result = get_secrets_path(input_str)

    parser = ArgumentParser(description="Get Vault variables path from user")
    parser.add_argument(
        "-p",
        "--path",
        default="variables",
        type=str,
        help="set vault variables path",
    )
    args = parser.parse_args()

    if len(result) >= 2:
        char_list = [chr(65 + i) for i in range(len(result))]  # Generates ['A', 'B']
        base_path = f"{os.environ.get(char_list[0])}/data"
        path_parent_group = f"{os.environ.get(char_list[0])}/data/{args.path}"
        export_env_vars_from_vault(path_parent_group)
        print(f"\nExtracting variables from base path: {path_parent_group}")
        for var in tqdm(char_list[1:]):
            base_path += f"/{os.environ.get(var)}"
            if var == char_list[len(char_list) - 1]:
                export_env_vars_from_vault(base_path)
            else:
                export_env_vars_from_vault(f"{base_path}/{args.path}")



#!/usr/bin/env python3

import json
from pathlib import Path


import boto3
import datetime
from dateutil.relativedelta import relativedelta

today = datetime.datetime.today()
year = datetime.datetime.now().year
day = datetime.datetime.now().day
month = datetime.datetime.now().month
end1 = datetime.datetime(year,month,1)+ relativedelta(months=1, days=-1)
start2 = datetime.datetime(year,month,day)
end2 = datetime.datetime(year,month,day)+ relativedelta(months=1, days=-1)
start1 = end1 + relativedelta(months=-2, days=1)
start = start1.strftime('%Y-%m-%d')
startC = start2.strftime('%Y-%m-%d')
endC = end2.strftime('%Y-%m-%d')
s=datetime.datetime(year,month,1)

sC = s.strftime('%Y-%m-%d')
cd = boto3.client('ce')

results = []
results1 = []
response1 = []
print('boto3 version')
print(boto3.__version__)
token = None
while True:
    if token:
        kwargs = {'NextPageToken': token}
    else:
        kwargs = {}

    data2 = cd.get_cost_forecast(TimePeriod={'Start': startC, 'End':  endC}, Granularity='MONTHLY', Metric="UNBLENDED_COST", **kwargs)
    results += data2['ForecastResultsByTime']
    token = data2.get('NextPageToken')
    if not token:
        break
token1 = None
while True:
    if token1:
        kwargs = {'NextPageToken': token}
    else:
        kwargs = {}
    data1 = cd.get_cost_and_usage(TimePeriod={ 'Start': sC, 'End': startC}, Granularity='MONTHLY', Metrics=['UnblendedCost'], **kwargs)
    results1 += data1['ResultsByTime']
    token1 = data1.get('NextPageToken')
    if not token1:
        break
response = cd.get_cost_and_usage(
    TimePeriod={
        'Start': sC,
        'End': startC
    },
    Granularity='MONTHLY',
    Metrics=[
        'BlendedCost'
    ],GroupBy=[
        {
            'Type': 'DIMENSION',
            'Key': 'SERVICE'
        }, ]
)
response1 += response['ResultsByTime']
#dans json
now = datetime.datetime.now()
date_time = now.strftime("%m/%d/%Y, %H:%M:%S")
dictionary ={
    "today": date_time,
    "total": results1[0],
    "Couts": response1[0],
    "prevus" : results[0],

}
path = Path("reports")
path.mkdir(parents=True, exist_ok=True)
with open('reports/cost.json','w',newline='') as f:  #Ouverture du fichier CSV en écriture
    print("file cost json created")
    json.dump(dictionary,f)               # Mettre dans la variable ecrire cette nouvelle ligne





import json
import os
import subprocess
from os.path import exists

import terragit.clone as clone
import terragit.gitlabFunctions as GitlabFunctions
import terragit.keybaseFunctions as keybaseFunctions
import terragit.terragrunt as terragrunt
import terragit.utilsFunctions as utils
from terragit.utilsFunctions import *


class TerraConf:
    def __init__(self):
        self.bcolor = terragrunt.bcolors

    def init_file(self):
        conf = {}
        for value in ["gitlab_token", "gitlab_username", "gitlab_url", "keybase"]:
            if value == "keybase":
                keybase_api = keybaseFunctions.KeybaseFunctions()
                verif = "false"
                while verif == "false":
                    val = input("Enter your " + value + ": ")
                    check = keybase_api.check_keybase_username_existance(str(val))
                    if check["them"][0] is None:
                        print(
                            self.bcolor.FAIL
                            + "this keybase username does not exist please retry"
                        )
                    else:
                        verif = "true"
            else:
                val = input("Enter your " + value + ": ")
            conf[value] = val
        exist = exists(os.path.expanduser(os.path.join("~/.terragit")))

        if not exist:

            file = open(os.path.expanduser(os.path.join("~/.terragit")), mode="w")
            file.write(
                '{ "gitlab_token": "'
                + conf["gitlab_token"]
                + '",\n'
                + '"gitlab_user": "'
                + conf["gitlab_username"]
                + '",\n'
                + '"gitlab_url": "'
                + conf["gitlab_url"]
                + '",\n'
                + '"keybase": "'
                + conf["keybase"]
                + '",\n'
                + '"projects": [] }\n '
            )
        else:
            file = open(os.path.expanduser(os.path.join("~/.terragit")))
            content = json.loads(file.read())
            file.close()
            file = open(os.path.expanduser(os.path.join("~/.terragit")), mode="w")
            content["gitlab_token"] = conf["gitlab_token"]
            content["gitlab_user"] = conf["gitlab_username"]
            content["gitlab_url"] = conf["gitlab_url"]
            content["keybase"] = conf["keybase"]

            json.dump(content, file, indent=3)
        file.close()
        print(self.bcolor.OKGREEN, " Terragit has been successfully initiated")

    def get_file_content(self):
        file = open(os.path.expanduser(os.path.join("~/.terragit")))

        json_object = json.loads(file.read())

        file.close()
        return json_object

    def list_projects(self, json_object):
        print(self.bcolor.OKGREEN, "your projects", json_object["projects"])

    def verif_file_and_credentials_existence(self):

        if exists(os.path.expanduser(os.path.join("~/.terragit"))):

            file = open(os.path.expanduser(os.path.join("~/.terragit")))

            json_object = json.loads(file.read())

            file.close()

            if (
                (len(json_object["gitlab_token"]) > 0)
                and (len(json_object["gitlab_user"]) > 0)
                and (len(json_object["keybase"]) > 0)
                and (len(json_object["gitlab_url"]) > 0)
            ):
                return json_object
        return "false"

    def get_selected_project(self, content):
        for grp_name in list(content.keys())[4:]:
            if content[grp_name]["selected"] == "true":
                print(
                    self.bcolor.OKGREEN,
                    " your Current selected project is ",
                    content[grp_name],
                )
                return content[grp_name]
        print(self.bcolor.WARNING, " no project is selected")

    def clone_and_switch(self, content, group_id, group_name, pwd):

        #

        colors = terragrunt.bcolors()

        gitlab_url = "https://gitlab.com"

        verif = self.verif_file_and_credentials_existence()
        print(colors.OKCYAN, "Cloning ...")
        clonn = clone.Clone(verif["gitlab_token"], gitlab_url, pwd)
        clonn.clone_projects(None, group_id)
        print(colors.OKCYAN, "Checking the existance of IAM user ...")
        utilsFunctions = utils.UtilsFunctions(verif["gitlab_token"], gitlab_url)
        gt = GitlabFunctions.GitlabFunctions(verif["gitlab_token"], gitlab_url)
        service_path = utilsFunctions.check_content_existance_in_serviceGr(
            group_id,
            None,
            "https://git@gitlab.allence.cloud/commons-acp/terraform/aws/user.git",
            'name="' + verif["gitlab_user"] + '"',
        )

        if "content_found" in service_path:
            print(colors.OKGREEN, "IAM user found!")

            self.add_credentials_to_group(
                gitlab_url,
                verif["gitlab_token"],
                group_id,
                None,
                pwd,
                "/" + service_path[29 : service_path.rindex("/")],
                "true",
            )
        else:
            print("IAM user not found")
            self.add_credentials_to_group(
                gitlab_url, verif["gitlab_token"], group_id, None, pwd, "", "false"
            )

        self.switch_project_existant(content, group_id, group_name)

    def current_path(self):
        pwd = os.popen("pwd").read().rstrip()
        pwd = pwd + "/"
        return pwd

    def goTo_or_create_folder(self, path):
        print("hello from fc go to")
        cmd = "mkdir " + path
        if subprocess.Popen(
            cmd, shell=True, stdin=None, stdout=subprocess.PIPE, stderr=subprocess.PIPE
        ):
            print("creating f")
            return path
        else:
            print(" f exists")
            return path

    def switch_project(self, content, group_id, group_name):
        if self.check_project_existance(content, group_id, group_name):
            print("project is already cloned!!")
            self.switch_project_existant(content, group_id, group_name)
        else:
            print("we are going to clone the project for you")
            pwd = os.popen("pwd").read().rstrip()
            pwd = pwd + "/"

            self.clone_and_switch(content, group_id, group_name, pwd)

    def check_project_existance(self, content, group_id, group_name):
        exist = False
        for grp_name in list(content.keys())[4:]:
            if group_name == grp_name:
                if content[group_name]["group_id"] == group_id:
                    exist = True
                    return exist
        return exist

    def switch_project_existant(self, content1, group_id, group_name):
        print("switch_project_existant")
        switched = True
        content = self.get_file_content()

        for grp_name in list(content.keys())[4:]:
            if group_name == grp_name:
                if content[group_name]["group_id"] == group_id:
                    content[group_name]["selected"] = "true"
                    if (
                        content[group_name]["aws_credentials"]["secret_access_key"]
                        != None
                    ):

                        cmd4 = "export GROUP_ID=" + group_id + "\n"
                        cmd3 = (
                            "export GITLAB_USER_NAME="
                            + content["gitlab_user"]
                            + " \n"
                            + " export gitlab_token="
                            + content["gitlab_token"]
                        )
                        cmd2 = (
                            "export AWS_SECRET_ACCESS_KEY="
                            + content[group_name]["aws_credentials"][
                                "secret_access_key"
                            ]
                        )
                        cmd1 = (
                            " \n export AWS_ACCESS_KEY_ID="
                            + content[group_name]["aws_credentials"]["access_key"]
                            + " \n "
                            + cmd2
                            + " \n "
                            + cmd3
                            + " \n "
                            + cmd4
                        )

                        f = open(
                            os.path.expanduser(os.path.join("~/.terragit_profile")), "w"
                        )
                        f.write(cmd1)
                        f.close()
                        cmd = "aws --version"
                        child = subprocess.Popen(
                            cmd,
                            stdin=subprocess.PIPE,
                            stdout=subprocess.PIPE,
                            shell=True,
                            encoding="utf8",
                        )
                        streamdata = child.communicate()[0]
                        print("streamdata", streamdata)
                        rc = child.returncode
                        print("rc", rc)
                        if rc >= 0:
                            cred = " echo you have no aws access_key to add for this profile/group/project "
                            print("aws-cli in installed")
                            if (
                                len(
                                    content[group_name]["aws_credentials"]["access_key"]
                                )
                                > 1
                            ):

                                aws_cmd = (
                                    "aws configure set aws_access_key_id  "
                                    ""
                                    + content[group_name]["aws_credentials"][
                                        "access_key"
                                    ]
                                    + " --profile "
                                    + group_name
                                )

                                cred = aws_cmd
                            if (
                                len(
                                    content[group_name]["aws_credentials"][
                                        "secret_access_key"
                                    ]
                                )
                                > 1
                            ):
                                aws_cmd1 = (
                                    "aws configure set aws_secret_access_key "
                                    + content[group_name]["aws_credentials"][
                                        "secret_access_key"
                                    ]
                                    + " --profile "
                                    + group_name
                                )
                                cred = cred + " && " + aws_cmd1

                            subprocess.Popen(
                                cred,
                                stdin=subprocess.PIPE,
                                stdout=subprocess.PIPE,
                                shell=True,
                                encoding="utf8",
                            )
                        else:
                            print("please install aws-cli first")
                    switched = "true"
                    print("Please run source ~/.terragit_profile")

            elif content[grp_name]["selected"] == "true":
                content[grp_name]["selected"] = "false"
        if not switched:
            print(self.bcolor.WARNING, " Error retrieving project")
        else:
            with open(os.path.expanduser(os.path.join("~/.terragit")), "w") as f:
                json.dump(content, f, indent=3)
            print(self.bcolor.OKGREEN, " Switch to project " + group_name + " succeded")

    def add_credentials_to_group(
        self, git_url, gitlab_token, group_id, project_id, path1, service_path, exist
    ):
        gitlab_functions1 = GitlabFunctions.GitlabFunctions(gitlab_token, git_url)
        if project_id == None:
            prj = gitlab_functions1.get_projects_of_group(group_id, 1, 10)
            for i in prj:
                prj_path = i["web_url"]
                group_name = gitlab_functions1.get_group_by_id(group_id)["name"]
                access_key_id = ""
                decrypted_secret_access_key = ""
                path = path1
                project_path = path
                if exist == "true":
                    print(self.bcolor.OKCYAN, "Getting & Decrypting credentials ...")
                    path = (
                        path + prj_path[len(git_url) + 1 : len(prj_path)] + service_path
                    )
                    cmd = (
                        "cd "
                        + path
                        + " && export gitlab_token="
                        + gitlab_token
                        + " && terragrunt output"
                    )
                    popen = subprocess.Popen(
                        cmd,
                        stdin=subprocess.PIPE,
                        stdout=subprocess.PIPE,
                        shell=True,
                        encoding="utf8",
                    )
                    lines = popen.communicate(input="\n")[0].split("\n")
                    access_key_id = ""
                    encrypted_secret_access_key = ""
                    for line in lines:
                        if "access_key_id" in line:
                            access_key_id = line[line.index('"') + 1 : line.rindex('"')]
                        if "encrypted_secret_access_key" in line:
                            encrypted_secret_access_key = line[
                                line.index('"') + 1 : line.rindex('"')
                            ]
                            decrypted_secret_access_key = (
                                "echo "
                                + '"'
                                + encrypted_secret_access_key
                                + '" |base64 --decode | keybase pgp decrypt'
                            )
                            decrypted_secret_access_key = os.popen(
                                decrypted_secret_access_key
                            ).read()
                else:
                    print(
                        self.bcolor.WARNING,
                        "You don't have an AWS account in this project...",
                    )
                print(self.bcolor.OKCYAN, "Adding project info to .terragit file ...")
                content = self.get_file_content()
                if {"name": group_name, "group_id": group_id} not in content[
                    "projects"
                ]:

                    content["projects"].append(
                        {"name": group_name, "group_id": group_id}
                    )

                    content[group_name] = {
                        "selected": "false",
                        "group_id": group_id,
                        "path": project_path,
                        "aws_credentials": {
                            "access_key": access_key_id,
                            "secret_access_key": decrypted_secret_access_key,
                        },
                    }
                    with open(
                        os.path.expanduser(os.path.join("~/.terragit")), "w"
                    ) as f:
                        json.dump(content, f, indent=3)
                elif {"name": group_name, "group_id": group_id} in content[
                    "projects"
                ] and content[group_name] == {
                    "selected": "false",
                    "group_id": group_id,
                    "path": project_path,
                    "aws_credentials": {"access_key": "", "secret_access_key": ""},
                }:
                    content[group_name] = {
                        "selected": "false",
                        "group_id": group_id,
                        "path": project_path,
                        "aws_credentials": {
                            "access_key": access_key_id,
                            "secret_access_key": decrypted_secret_access_key,
                        },
                    }
                    with open(
                        os.path.expanduser(os.path.join("~/.terragit")), "w"
                    ) as f:
                        json.dump(content, f, indent=3)
                else:
                    print("content existant dans .terragit!!")
                print(
                    self.bcolor.OKGREEN,
                    "Project information has been successfully added to .terragit",
                )

        else:
            TerraConf.add_credentials(
                self,
                git_url,
                gitlab_token,
                group_id,
                project_id,
                path1,
                service_path,
                exist,
            )

    def add_credentials(
        self, git_url, gitlab_token, group_id, project_id, path, service_path, exist
    ):
        gitlab_functions1 = GitlabFunctions.GitlabFunctions(gitlab_token, git_url)
        prj_path = gitlab_functions1.get_project_by_id(project_id)["web_url"]
        group_name = gitlab_functions1.get_group_by_id(group_id)["name"]
        access_key_id = ""
        decrypted_secret_access_key = ""
        project_path = path
        if exist == "true":
            print(self.bcolor.OKCYAN, "Getting & Decrypting credentials ...")
            path = path + prj_path[len(git_url) + 1 : len(prj_path)] + service_path
            cmd = (
                "cd "
                + path
                + " && export gitlab_token="
                + gitlab_token
                + " && terragrunt output"
            )
            popen = subprocess.Popen(
                cmd,
                stdin=subprocess.PIPE,
                stdout=subprocess.PIPE,
                shell=True,
                encoding="utf8",
            )
            lines = popen.communicate(input="\n")[0].split("\n")
            access_key_id = ""
            encrypted_secret_access_key = ""
            for line in lines:
                if "access_key_id" in line:
                    access_key_id = line[line.index('"') + 1 : line.rindex('"')]
                if "encrypted_secret_access_key" in line:
                    encrypted_secret_access_key = line[
                        line.index('"') + 1 : line.rindex('"') - 1
                    ]
            decrypted_secret_access_key = (
                "echo "
                + encrypted_secret_access_key
                + " | base64 --decode | keybase pgp decrypt"
            )
            decrypted_secret_access_key = os.popen(decrypted_secret_access_key).read()
        else:
            print(
                self.bcolor.WARNING, "You don't have an AWS account in this project..."
            )
        print(self.bcolor.OKCYAN, "Adding project info to .terragit file ...")
        content = self.get_file_content()
        if {"name": group_name, "group_id": group_id} not in content["projects"]:
            content["projects"].append({"name": group_name, "group_id": group_id})
            content[group_name] = {
                "selected": "false",
                "group_id": group_id,
                "path": project_path,
                "aws_credentials": {
                    "access_key": access_key_id,
                    "secret_access_key": decrypted_secret_access_key,
                },
            }
            with open(os.path.expanduser(os.path.join("~/.terragit")), "w") as f:
                json.dump(content, f, indent=3)
        print(
            self.bcolor.OKGREEN,
            "Project information has been successfully added to .terragit",
        )



import requests # token : gitlab_token
import os
import sys


def clone_projects(grp_id):
    url_projets= git_url+"groups/"+str(grp_id)+"/projects"
    print(url_projets," url_projets")
    projets  = requests.get(url_projets, headers=headers).json()
    print(projets," projetS")
    for project in projets :
        print(project," project")
        path = root_path+project['path_with_namespace']
        if not os.path.isdir(path):
            os.makedirs(path)
            cmd = "git clone "+project['ssh_url_to_repo'] +" "+path
            stream = os.popen(cmd)
    url_grps = git_url+"groups/"+str(grp_id)+"/subgroups"
    subgroups = requests.get(url_grps, headers=headers).json()
    for subgroup in subgroups :
        clone_projects(subgroup['id'])

#"https://gitlab.com/"
#gitlab_token = os.environ['gitlab_token']
#root_path = "/tmp/"
#grp_id=10859288

grp_id = sys.argv[1]
root_path = sys.argv[2]

gitlab_token = os.environ['gitlab_token']
git_url = "https://gitlab.allence.cloud/"+"api/v4/"
if len(sys.argv) > 3:
    git_url = sys.argv[3]+"api/v4/"

headers = {'PRIVATE-TOKEN': gitlab_token}
clone_projects(str(grp_id))



import os
from os import listdir
from os.path import isdir, join
import subprocess
import sys
import shutil
import pathlib

class bcolors:

    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'


def tg_plan(path,logsFolder):
    only_tf_files=[f for f in  sorted(listdir(path)) if not isdir(join(path, f)) and f.endswith('.tf')]
    if len(only_tf_files)==0:
        onlyDirectories = [d for d in sorted(listdir(path)) if isdir(join(path, d)) and d !=".terraform" and d != ".terragrunt-cache"]
        if(len(onlyDirectories) > 0):
            for i in range(0, len(onlyDirectories)):
                tg_plan(path+"/"+onlyDirectories[i],logsFolder)
        return

    os.chdir(path)
    logfileName=path.split("live/")[1].replace("/","_")
    state_list = ("terragrunt plan -no-color 2>&1 | tee " +logsFolder+"/"+logfileName+".log")
    popen = subprocess.Popen(state_list, stdout = subprocess.PIPE, shell = True, encoding = 'utf8')

    lines = popen.stdout.readlines()
    popen.stdout.close()
    print(bcolors.OKBLUE+path+":" +bcolors.ENDC)
    for line in lines:
        if("No changes. Infrastructure is up-to-date." in line):
            print(bcolors.OKGREEN +"  : No changes. Infrastructure is up-to-date."+ bcolors.ENDC)
            return
        if("Plan:" in line):
            print(bcolors.WARNING +line+ bcolors.ENDC)
            return
        if ("will be updated in-place" in line):
            print(line.replace('\n',''))
        if ("will be created" in line):
            print(line.replace('\n',''))
        if ("must be replaced" in line):
            print(line.replace('\n',''))

            lint=lines[(lines.index(line)):(len(lines))]
            lin=lint[0:(lint.index('\n'))]
            for l in lin:
                if ("forces replacement" in l):
                    print(l.replace('\n',''))
                    print(lin[(lin.index(l))+1])
        if ("will be destroyed" in line):
            print(line.replace('\n',''))
        if (line.startswith("Error")):
            lint=lines[(lines.index(line)):(len(lines))]
            for l in lint:
                print(l.replace('\n',''))
            print(bcolors.FAIL +" COULDNT PROCESS"+ bcolors.ENDC)
            failedloglist.append(path)
            return
    print(bcolors.FAIL +" COULDNT PROCESS"+ bcolors.ENDC)
    failedloglist.append(path)

rootPath = sys.argv[1]
failedloglist=[]
logsFolder=pathlib.Path("logs").absolute().as_posix()
failedlogsFolder=pathlib.Path("failedlogs").absolute().as_posix()

tg_plan(rootPath,logsFolder)

if failedloglist:
    for message in failedloglist:
        logfileName=message.split("live/")[1].replace("/","_")
        os.chdir(failedlogsFolder)
        shutil.move(logsFolder+"/"+logfileName+".log", "failed_"+logfileName+".log")
    sys.exit(1)




import os

import requests  # token : gitlab_token

import terragit.terragrunt as terraconf


class Clone:
    def __init__(self, gitlab_token, git_url, root_path):
        self.root_path = root_path
        self.gitlab_token = gitlab_token
        self.git_url = git_url
        self.bcolor = terraconf.bcolors

    def clone_projects(self, project_id, grp_id, path):

        if path != None and path != "./":
            headers = {"PRIVATE-TOKEN": self.gitlab_token}
            if path != None:
                root_path = os.path.abspath(path)

            if project_id != None:

                url_projets = self.git_url + "/api/v4/projects/" + str(project_id)
                project = requests.get(url_projets, headers=headers).json()
                path = root_path + "/" + project["path_with_namespace"]
                if not os.path.isdir(path):
                    os.makedirs(path)

                    cmd = "cd " + path + " && git clone " + project["ssh_url_to_repo"]
                    os.system(cmd)

                else:
                    print(f"{path} already exists")

            if grp_id != None:

                url_projets = (
                    self.git_url + "/api/v4/groups/" + str(grp_id) + "/projects"
                )

                projets = requests.get(url_projets, headers=headers).json()
                for project in projets:

                    path = root_path + "/" + project["path_with_namespace"]

                    if not os.path.isdir(path):
                        os.makedirs(path)
                        cmd = (
                            "cd " + path + " && git clone " + project["ssh_url_to_repo"]
                        )
                        os.system(cmd)
                    else:
                        print(f"{path} already exists")

                url_grps = self.git_url + "/api/v4/groups/" + str(grp_id) + "/subgroups"
                subgroups = requests.get(url_grps, headers=headers).json()
                for subgroup in subgroups:
                    self.clone_projects(None, subgroup["id"])
        else:
            print(
                self.bcolor.FAIL,
                " Can you provide a path for directory to make the clone when passing the args!!",
            )

    def list_project(self, path):
        info_list = []
        group_id = 0
        user_input = ""
        headers = {"PRIVATE-TOKEN": self.gitlab_token}
        url_group = self.git_url + "/api/v4/groups/2875/descendant_groups"
        groups = requests.get(url_group, headers=headers).json()

        name_list = []

        for g in groups:
            data = {}
            data["name"] = g["name"]
            data["id"] = g["id"]

            info_list.append(data)
            name_list.append(g["name"])

        input_message = "Pick an option:\n"
        for index, item in enumerate(name_list):
            input_message += f"{index+1}) {item}\n"
        input_message += "Make a choice to clone group: "
        while user_input.lower() not in name_list:
            user_input = input(input_message)
        print("You picked: " + user_input)

        for j in info_list:
            if user_input == j["name"]:
                group_id = j["id"]

        if path != None:
            self.clone_projects(None, group_id, path)
        else:
            print(
                self.bcolor.FAIL,
                " Can you provide a path for directory to make the clone when passing the args!!",
            )



import shutil
import subprocess
import json
import requests
from terragit.terragrunt import *  # type: ignore
import gitlab

logsFolder = ""
pathList = []
failedloglist = []
notif_paths = []
printLogs = False

class bcolors:
    HEADER = "\033[95m"
    OKBLUE = "\033[94m"
    OKCYAN = "\033[96m"
    OKGREEN = "\033[92m"
    WARNING = "\033[93m"
    FAIL = "\033[91m"
    ENDC = "\033[0m"
    BOLD = "\033[1m"
    UNDERLINE = "\033[4m"


class apply_changes:
    def __init__(self):
        self.bcolor = bcolors

    def apply_ci(self):
        global printLogs
        git_url = f"https://{os.environ.get('CI_SERVER_HOST')}"
        logsFolder = pathlib.Path("logs").absolute().as_posix()
        idProject = int(str(os.environ.get("CI_PROJECT_ID")))
        idCommit = str(os.environ.get("CI_COMMIT_SHA"))
        gitlab_token = str(os.environ.get("gitlab_token"))
        ci_commit_title = str(os.environ.get("CI_COMMIT_TITLE"))

        gl = gitlab.Gitlab(url=git_url, private_token=gitlab_token)
        project = gl.projects.get(idProject)
        commit = project.commits.get(idCommit)
        diff = commit.diff()
        folderList = []

        if len(diff) == 0:
            if not isdir(pathlib.Path(ci_commit_title).absolute().as_posix()):
                print(
                    bcolors.FAIL
                    + ci_commit_title
                    + " is not valid path "
                    + bcolors.ENDC
                )
            else:
                ci_commit_titlePath = (
                    pathlib.Path(ci_commit_title).absolute().as_posix()
                )
                printLogs = True
                self.apply(ci_commit_titlePath, logsFolder, printLogs)
        else:
            for change in diff:
                newPath = change["new_path"]
                notif_paths.append(newPath)
                if not ("live/") in newPath:
                    print(
                        pathlib.Path(newPath).absolute().as_posix()
                        + bcolors.WARNING
                        + " OUT of SCOPE"
                        + bcolors.ENDC
                    )
                else:
                    pathh = pathlib.Path(newPath).parent.absolute().as_posix()
                    folderList.append(pathh)
        mylist = list(dict.fromkeys(folderList))
        if os.environ.get("TG_OUTPUT_LIMIT"):
            TG_OUTPUT_LIMIT = int(str(os.environ.get("TG_OUTPUT_LIMIT")))
        else:
            TG_OUTPUT_LIMIT = 3
        if len(mylist) <= TG_OUTPUT_LIMIT:
            printLogs = True
        failedlogsFolder = pathlib.Path("failedlogs").absolute().as_posix()
        for path in mylist:
            if isdir(path):
                self.apply(path, logsFolder, printLogs)
        if failedloglist:
            for message in failedloglist:
                logfileName = message.split("live/")[1].replace("/", "_")
                os.chdir(failedlogsFolder)
                shutil.move(
                    logsFolder + "/" + logfileName + ".log",
                    "failed_" + logfileName + ".log",
                )
            sys.exit(1)

    def apply(self, path, logsFolder, printLogs):
        success_detected = False
        if path in pathList:
            return
        else:
            pathList.append(path)
            only_tf_files = [
                f
                for f in sorted(listdir(path))
                if not isdir(join(path, f)) and f.endswith(".tf")
            ]
            if len(only_tf_files) == 0:
                onlyDirectories = [
                    d
                    for d in sorted(listdir(path))
                    if isdir(join(path, d))
                    and d != ".terraform"
                    and d != ".terragrunt-cache"
                ]
                if len(onlyDirectories) > 0:
                    for i in range(0, len(onlyDirectories)):
                        self.apply(
                            path + "/" + onlyDirectories[i], logsFolder, printLogs
                        )
                return
            os.chdir(path)
            logfileName = path.split("live/")[1].replace("/", "_")
            state_list = (
                f"terragrunt apply -auto-approve -no-color 2>&1 | tee {logsFolder}/{logfileName}.log"
            )
            popen = subprocess.Popen(
                state_list, stdout=subprocess.PIPE, shell=True, encoding="utf8"
            )
            lines = popen.stdout.readlines()  # type: ignore
            popen.stdout.close()  # type: ignore
            print(bcolors.OKBLUE + path + ":" + bcolors.ENDC)

            for line in lines:
                if printLogs:
                    print(line)
                if "Apply complete! Resources:" in line:
                    success_detected = True
                    print(bcolors.OKGREEN + line + bcolors.ENDC)
                    discord_api = os.environ.get("DISCORD_API")
                    var = self.user()
                    if discord_api != None:
                        payload = {"content": f"{line} for user {var} in {notif_paths}"}
                        json_message = json.dumps(payload, indent=4)
                        headers = {"Content-Type": "application/json; charset=UTF-8"}
                        requests.post(discord_api, data=json_message, headers=headers)
                    else:
                        print(
                            self.bcolor.WARNING
                            + " You haven't set yet your webhook for your group "
                        )
                    continue
                elif "Error" in line:
                    if not success_detected:
                        lint = lines[(lines.index(line)) : (len(lines))]
                        for l in lint:
                            print(l.replace("\n", ""))
                        print(
                            bcolors.FAIL
                            + " COULDNT PROCESS , Terraform apply failed. Fix errors and run the script again!"
                        )
                        failedloglist.append(path)
                        break



    def user(self):
        state_list = 'aws sts get-caller-identity --query "Arn" --output text'
        popen = subprocess.Popen(
            state_list, stdout=subprocess.PIPE, shell=True, encoding="utf8"
        )
        lines = popen.stdout.readlines()  # type: ignore
        return lines[0]



import argparse

import semver

parser = argparse.ArgumentParser()
parser.add_argument("-m", "--minor", dest="minor", type=bool)
parser.add_argument("-p", "--patch", dest="patch", type=bool)
parser.add_argument("-M", "--major", dest="major", type=bool)
args = parser.parse_args()

filePath = f"VERSION"

# Read the current version from the VERSION file
with open(filePath, "r") as f:
    version = f.read().strip()
    version = semver.Version.parse(version)
    print("currrent version ", version)

# Increment the patch version
if args.patch:
    new_version = version.bump_patch()
    with open(filePath, "w") as f:
        f.write(str(new_version))
        print("new patch version ", new_version)

# Increment the miner version
if args.minor:
    new_version = version.bump_minor()
    with open(filePath, "w") as f:
        f.write(str(new_version))
        print("new minor version ", new_version)

# Increment the major version
if args.major:
    new_version = version.bump_major()
    with open(filePath, "w") as f:
        f.write(str(new_version))
        print("new major version ", new_version)



import requests
import os
import time

gitlab_token = os.environ.get("GITLAB_TOKEN")
projet_infra=os.getenv("PROJET_INFRA")
project_name = os.getenv("PROJECT_GROUP").replace('/','%2F')+"%2F"+projet_infra
branch_name = os.getenv("TERRAGRUNT_GIT_BRANCH")
headers = {'PRIVATE-TOKEN': gitlab_token}
base_url = "https://gitlab.allence.cloud/api/v4/projects/"
## GET INFRA PROJECT ID
project_url = base_url+project_name
req_project = requests.get(project_url, headers=headers).json()
project_id = req_project['id']
## GET INFRA MR ID
branch_url=base_url+str(project_id)+"/repository/branches/"+branch_name
req_branch=requests.get(branch_url, headers=headers).json()
commit_sha = req_branch['commit']['id']
print("commit ID = "+str(commit_sha))

mr_url=base_url+str(project_id)+"/repository/commits/"+commit_sha+"/merge_requests"
req_mr=requests.get(mr_url, headers=headers).json()
#print(req_mr)
mr_id = req_mr[0]['iid']
mr_title= req_mr[0]['title']
print("MR ID = "+str(mr_id))


mrs_url = base_url+str(project_id)+"/merge_requests?state=opened"
req_mrs =requests.get(mrs_url, headers=headers).json()
#print(req_mrs)
if('error' in req_mrs):
    print("Everything is fine no open MRs for this env")
else :
    for mr in req_mrs :
        if mr['iid'] != mr_id and mr['title']==mr_title:
            print("DELETE "+base_url+str(project_id)+"/merge_requests/"+str(mr['iid']))
            r = requests.delete(base_url+str(project_id)+"/merge_requests/"+str(mr['iid']), headers=headers)
            print("MR "+str(mr['iid'])+" is Closed, status: "+str(r))



from setuptools import find_packages, setup

classifiers = [
    "Development Status :: 5 - Production/Stable",
    "Operating System :: Microsoft :: Windows :: Windows 10",
    "License :: OSI Approved :: MIT License",
    "Programming Language :: Python :: 3",
]



setup(
    name="terragit",
    version="0.3.77",
    description="terragit package",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://gitlab.com/commons-acp/python/terraform-gitlab",
    author="hana.mansia",
    author_email="hana.mansia@allence-tunisie.com",
    maintainer="hana.mansia",
    maintainer_email="hana.mansia@allence-tunisie.com",
    keywords=[
        "terragit",
        "terraform",
        "git",
        "automation",
        "gitlab",
        "pipeline",
        "ci/cd",
    ],
    license="MIT",
    classifiers=classifiers,
    packages=find_packages(),
    install_requires=["pandas"],
    entry_points=({"console_scripts": ["terragit = terragit.__main__:main"]}),
)
